@@ -15,7 +15,14 @@
 Package mediating dbus actions.
 """
 
+from ._bind import BindActions, RebindActions
 from ._constants import BLOCKDEV_INTERFACE, FILESYSTEM_INTERFACE, POOL_INTERFACE
+from ._debug import (
+    BlockdevDebugActions,
+    FilesystemDebugActions,
+    PoolDebugActions,
+    TopDebugActions,
+)
 from ._logical import LogicalActions
 from ._physical import PhysicalActions
 from ._pool import PoolActions
